..
    SPDX-License-Identifier: AGPL-3.0-or-later
    Copyright (C) 2025  Dionisis Toulatos

Utils
#####

.. automodule:: nirahmq.utils
    :members:

.. autoattribute:: nirahmq.utils.Optional

    A custom type alias that marks a variable as of types ``T`` or ``Unset``.

.. autoattribute:: nirahmq.utils.Required

    A custom type used by :py:class:`nirahmq.components.base.ComponentBase` to
    mark a class field as required during serialization.
